@@ -58,6 +58,21 @@ class TestRstDirectives(unittest.TestCase):
         self.assertEqual(True, options['noviewbox'])
         self.assertEqual(True, options['inline_svg'])
 
+    @capture_stderr
+    def test_cleanup(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir, noviewbox=False)
+        text = (".. nwdiag::\n"
+                "\n"
+                "   plugin autoclass\n"
+                "   network {"
+                "     A"
+                "     B"
+                "   }")
+        publish_doctree(text)
+
+        from blockdiag import plugins
+        self.assertEqual([], plugins.loaded_plugins)
+
     def test_setup_fontpath1(self):
         with self.assertRaises(RuntimeError):
             directives.setup(format='SVG', fontpath=['dummy.ttf'],
