@@ -13,6 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import sys
 import packetdiag
 import packetdiag.builder
 import packetdiag.drawer
@@ -24,5 +25,5 @@ class PacketdiagApp(Application):
     module = packetdiag
 
 
-def main():
-    return PacketdiagApp().run()
+def main(args=sys.argv[1:]):
+    return PacketdiagApp().run(args)
